﻿// PlaceHolderAssignRecordAction.cs
//
// Erstellt einen neuen Menüpunkt unter "Betriebsmittel|Platzhalter" um einem
// Platzhalterobjekt einen Wertesatz zuweisen zu können.
// Diesem Menüpunkt kann dann eine Tastenkombination (z.B. ALT + W)  zugewiesen werden.
//
// letzte Änderung:
// V1.0.0, 23.04.2009, Frank Schöneck, Projektbeginn
// V2.0.0, 23.04.2009, Frank Schöneck, Funktioniert nun auch aus dem Platzhalterobjekte-Dialog
//                                     Neue Position des Menüpunktes unter 'Einfügen'
// V2.1.0, 14.03.2011, Frank Schöneck, Anzeige aktualisieren hinzugefügt
// V3.0.0, 24.11.2021, Frank Schöneck, Angepasst an die Ribbon-Technik der EPLAN Plattform 2022
//
// Copyright by Frank Schöneck, 2009-2021
//
// für Eplan Electric P8, ab V2022
//

public class PlaceHolderAssignRecordClass
{
	string m_TabName = "Betriebsmittel";
	string m_commandGroupName = "Platzhalterobjekt";
	string m_commandName = "Wertesatz zuweisen";

	[DeclareRegister]
	public void registerRibbonItems()
	{
		var newTab = new Eplan.EplApi.Gui.RibbonBar().GetTab(m_TabName);
		var commandGroup = newTab.CommandGroups.FirstOrDefault(item => item.Name == m_commandGroupName);
		if (commandGroup == null) //CommandGroup noch nicht vorhanden, dann neu erzeugen
		{
			commandGroup = newTab.AddCommandGroup(m_commandGroupName);
		}
		commandGroup.AddCommand(m_commandName, "PlaceHolderAssignRecordAction", m_commandName, "Ruft den Dialog 'Wertesatz zuweisen' auf");
	}

	[DeclareUnregister]
	public void unRegisterRibbonItems()
	{
		//Command entfernen
		var vTab = new Eplan.EplApi.Gui.RibbonBar().Tabs.FirstOrDefault(item => item.Name == m_TabName);
		if (vTab != null)
		{
			var commandGroup = vTab.CommandGroups.FirstOrDefault(item => item.Name == m_commandGroupName);
			if (commandGroup != null)
			{
				var command = commandGroup.Commands.Values.FirstOrDefault(item => item.Text == m_commandName);
				if (command != null)
				{
					command.Remove();
				}
				//Wenn CommandGroup leer ist diese auch entfernen
				if (commandGroup.Commands.Count == 0)
				{
					commandGroup.Remove();
				}
			}
		}
	}

	[DeclareAction("PlaceHolderAssignRecordAction")]
	public void PlaceHolderAssignRecordAction()
	{
		CommandLineInterpreter oCLI = new CommandLineInterpreter();
		oCLI.Execute("XMPlaceHolderAssignRecordAction");
		oCLI.Execute("ProjectOptionsGuiIGfWindOnAssignRecord");
		//Anzeige aktualisieren
		oCLI.Execute("XGedRedrawAction");
		return;
	}

}
